@@ -107,4 +107,18 @@ report_email_1 =''
 report_email_2 =''
 serial=''
 
-    
+test_basic_info = False
+def signedIn():
+    return sign_in_token!='' and test_basic_info == True
+def singn_out_clear():
+    global sign_in_user, sign_in_token,test_place,test_city,test_country,test_provider,report_email_1,report_email_2,test_basic_info
+    sign_in_user =''
+    sign_in_token =''
+    test_place =''
+    test_city  =''
+    test_country =''
+    test_provider =''
+    report_email_1 =''
+    report_email_2 =''
+    test_basic_info = False
+
