@@ -225,7 +225,7 @@ class CassettePolling(threading.Thread):
         if(status == DEVICE_STATE_CASSETTE_POLLED):
             self.notify( [self.slotIndex, DEVICE_STATE_CASSETTE_POLLED, '', 'no change'])
         elif(status == DEVICE_STATE_CASSETTE_VALID):
-            if main_paras.sign_in_token == '':
+            if not main_paras.signedIn():
                 main_paras.queueForGui.put([SIGN_IN_FIRST_INDEX,'','',''])
             else:
                 self.startTakePhotoProcedure(qr_code,self.qCom)
@@ -234,7 +234,7 @@ class CassettePolling(threading.Thread):
 #                 print('manual waiting qr')
             pass            
         else:
-            if main_paras.sign_in_token == '' and status != DEVICE_STATE_CASSETTE_EMPTY:
+            if (not main_paras.signedIn()) and status != DEVICE_STATE_CASSETTE_EMPTY:
                 main_paras.queueForGui.put([SIGN_IN_FIRST_INDEX,'','',''])
             else:
                 self.stopTakePhotoProcedure()
