@@ -3,21 +3,20 @@ import cv2
 import random
 from shutil import copyfile
 import threading
-import sys
-import threading
 import ntpath
-import os
 
-if __name__ == "__main__":
-    import sys, os, inspect
-    currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
-    parentdir = os.path.dirname(currentdir)
-    sys.path.insert(0, parentdir)
+
+import sys, os, inspect
+currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
+sys.path.insert(0, currentdir)
+parentdir = os.path.dirname(currentdir)
+sys.path.insert(0, parentdir)
 
 
 from define import *
-from test_handler.calibration import crop_rotate
-from test_handler.qr_identify import qrIdentify
+from calibration import crop_rotate, final_save
+from qr_identify import qrIdentify
+from alg import target
 
 def camInstCreate(cameraIndex):
     try:
@@ -43,13 +42,18 @@ def takePhoto(cameraIndex,qrCode,event):
         try:
             cam=camInstCreate(cameraIndex)
             s, img=cam.read()
+#             time.sleep(1)
+#             s, img=cam.read()
             if s:
                 print('got image')
-#                cv2.imwrite(str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.jpg', img)
+                #cv2.imwrite(str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.jpg', img)
                 if qrCode!=None:   ## got Qr code, regular picture for detection.
                     photo=qrCode+'_'+str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.jpg'
                     imageFile=IMG_PATH+photo
-                    if crop_rotate(img,imageFile):
+                    first_crop = crop_rotate(img)
+                    final_img, _ = target.adjust(img, first_crop)
+                    #cv2.imwrite(str(int(time.time())) + '_clh_'+time.strftime('%Y%m%d%H%M%S')+'.jpg', final_img[1])
+                    if final_save(final_img[0],imageFile):
                         cam.release()
                         camera_sem.release()
                         rtn=photo
